==> activity-center-api-2.9.21-20180718.035227-1-sources.jar: cn/com/duiba/activity/center/api/dto/book/BookInfoDto.java <==
package cn.com.duiba.activity.center.api.dto.book;

import java.io.Serializable;

public class BookInfoDto implements Serializable {

    private static final long serialVersionUID = -2407435876793197370L;

    private Long id;

    private String bookImg;

    private String bookName;

    private String bookAuthor;

    private String bookDesc;

    private String inLink;

    private String outLink;

    private Long maxBallot;

    private Integer bookType;

    private boolean userBallot;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getBookImg() {
        return bookImg;
    }

    public void setBookImg(String bookImg) {
        this.bookImg = bookImg;
    }

    public String getBookName() {
        return bookName;
    }

    public void setBookName(String bookName) {
        this.bookName = bookName;
    }

    public String getBookAuthor() {
        return bookAuthor;
    }

    public void setBookAuthor(String bookAuthor) {
        this.bookAuthor = bookAuthor;
    }

    public String getBookDesc() {
        return bookDesc;
    }

    public void setBookDesc(String bookDesc) {
        this.bookDesc = bookDesc;
    }

    public String getInLink() {
        return inLink;
    }

    public void setInLink(String inLink) {
        this.inLink = inLink;
    }

    public String getOutLink() {
        return outLink;
    }

    public void setOutLink(String mbLink) {
        this.outLink = outLink;
    }

    public Long getMaxBallot() {
        return maxBallot;
    }

    public void setMaxBallot(Long maxBallot) {
        this.maxBallot = maxBallot;
    }

    public Integer getBookType() {
        return bookType;
    }

    public void setBookType(Integer bookType) {
        this.bookType = bookType;
    }

    public boolean isUserBallot() {
        return userBallot;
    }

    public void setUserBallot(boolean userBallot) {
        this.userBallot = userBallot;
    }

}

==> activity-center-api-3.4.24-sources.jar: cn/com/duiba/activity/center/api/dto/book/BookInfoDto.java <==
package cn.com.duiba.activity.center.api.dto.book;

import java.io.Serializable;

public class BookInfoDto implements Serializable {

    private static final long serialVersionUID = -2407435876793197370L;

    private Long id;

    private String bookImg;

    private String bookName;

    private String bookAuthor;

    private String bookDesc;

    private Long maxBallot;

    private Integer bookType;

    private boolean userBallot;
    //开发者书籍id
    private Long bookId;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getBookImg() {
        return bookImg;
    }

    public void setBookImg(String bookImg) {
        this.bookImg = bookImg;
    }

    public String getBookName() {
        return bookName;
    }

    public void setBookName(String bookName) {
        this.bookName = bookName;
    }

    public String getBookAuthor() {
        return bookAuthor;
    }

    public void setBookAuthor(String bookAuthor) {
        this.bookAuthor = bookAuthor;
    }

    public String getBookDesc() {
        return bookDesc;
    }

    public void setBookDesc(String bookDesc) {
        this.bookDesc = bookDesc;
    }

    public Long getMaxBallot() {
        return maxBallot;
    }

    public void setMaxBallot(Long maxBallot) {
        this.maxBallot = maxBallot;
    }

    public Integer getBookType() {
        return bookType;
    }

    public void setBookType(Integer bookType) {
        this.bookType = bookType;
    }

    public boolean isUserBallot() {
        return userBallot;
    }

    public void setUserBallot(boolean userBallot) {
        this.userBallot = userBallot;
    }

    public Long getBookId() {
        return bookId;
    }

    public void setBookId(Long bookId) {
        this.bookId = bookId;
    }
}
